@@ -33,14 +33,14 @@ def game(incoming):
     else:
         print('The 2nd number odd')
     if mod_num3 == 1:
-        print('The 2nd number even')
+        print('The 3rd number even')
     else:
-        print('The 2nd number odd')
+        print('The 3rd number odd')
 
     print('The 4th number is 1/3 of: ' + str(div_num4))
 
     while True:
-        print('Lives:' + str(lives))
+        print('\nLives:' + str(lives) + '\n')
         in_list = input().split()
         guess_added = 0
         guess_multi = 1
@@ -80,4 +80,4 @@ def main_func():
 
 
 if __name__ == '__main__':
-    main_func()
+    main_func()
\ No newline at end of file
